@@ -252,6 +252,20 @@ function templates(tpl,key) {
       "_nodes" : [
          {
             "_nodes" : [
+               {
+                  "default" : 0,
+                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsRequirePkce",
+                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsRequirePkce",
+                  "title" : "oidcOPMetaDataOptionsRequirePkce",
+                  "type" : "bool"
+               },
+               {
+                  "default" : 0,
+                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsStoreIDToken",
+                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsStoreIDToken",
+                  "title" : "oidcOPMetaDataOptionsStoreIDToken",
+                  "type" : "bool"
+               },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsConfigurationURI",
                   "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsConfigurationURI",
@@ -275,23 +289,10 @@ function templates(tpl,key) {
                   "title" : "oidcOPMetaDataOptionsClientSecret",
                   "type" : "password"
                },
-               {
-                  "default" : 0,
-                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsStoreIDToken",
-                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsStoreIDToken",
-                  "title" : "oidcOPMetaDataOptionsStoreIDToken",
-                  "type" : "bool"
-               },
                {
                   "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsUserAttribute",
                   "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsUserAttribute",
                   "title" : "oidcOPMetaDataOptionsUserAttribute"
-               },
-               {
-                  "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsRequirePkce",
-                  "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsRequirePkce",
-                  "title" : "oidcOPMetaDataOptionsRequirePkce",
-                  "type" : "bool"
                }
             ],
             "id" : "oidcOPMetaDataOptionsConfiguration",
@@ -358,7 +359,6 @@ function templates(tpl,key) {
                   "title" : "oidcOPMetaDataOptionsAcrValues"
                },
                {
-                  "default" : "get",
                   "get" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsAuthnEndpointAuthMethod",
                   "id" : tpl+"s/"+key+"/"+"oidcOPMetaDataOptionsAuthnEndpointAuthMethod",
                   "select" : [
@@ -655,6 +655,11 @@ function templates(tpl,key) {
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAdditionalAudiences",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAdditionalAudiences",
                   "title" : "oidcRPMetaDataOptionsAdditionalAudiences"
+               },
+               {
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsTokenXAuthorizedRP",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsTokenXAuthorizedRP",
+                  "title" : "oidcRPMetaDataOptionsTokenXAuthorizedRP"
                }
             ],
             "id" : "oidcRPMetaDataOptionsAdvanced",
@@ -692,6 +697,13 @@ function templates(tpl,key) {
                   "title" : "oidcRPMetaDataOptionsRequirePKCE",
                   "type" : "bool"
                },
+               {
+                  "default" : 0,
+                  "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRefreshTokenRotation",
+                  "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRefreshTokenRotation",
+                  "title" : "oidcRPMetaDataOptionsRefreshTokenRotation",
+                  "type" : "bool"
+               },
                {
                   "default" : 0,
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAllowOffline",
@@ -758,24 +770,28 @@ function templates(tpl,key) {
                   "type" : "select"
                },
                {
+                  "default" : 0,
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthRequiredForAuthorize",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthRequiredForAuthorize",
                   "title" : "oidcRPMetaDataOptionsAuthRequiredForAuthorize",
                   "type" : "bool"
                },
                {
+                  "default" : 0,
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnRequireState",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnRequireState",
                   "title" : "oidcRPMetaDataOptionsAuthnRequireState",
                   "type" : "bool"
                },
                {
+                  "default" : 0,
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnRequireNonce",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsAuthnRequireNonce",
                   "title" : "oidcRPMetaDataOptionsAuthnRequireNonce",
                   "type" : "bool"
                },
                {
+                  "default" : 0,
                   "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserinfoRequireHeaderToken",
                   "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsUserinfoRequireHeaderToken",
                   "title" : "oidcRPMetaDataOptionsUserinfoRequireHeaderToken",
@@ -1761,8 +1777,7 @@ function templates(tpl,key) {
       ],
       "help" : "authsaml.html#options",
       "id" : "samlIDPMetaDataOptions",
-      "title" : "samlIDPMetaDataOptions",
-      "type" : "simpleInputContainer"
+      "title" : "samlIDPMetaDataOptions"
    },
    {
       "_nodes" : [
